#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-gadt-plugin-2.3.0.0-2TvPh8QGxerFYl5PoF1MSq
key:                  hls-gadt-plugin-2.3.0.0-2TvPh8QGxerFYl5PoF1MSq
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  ae7cf26badfcbbc9a708b43bb6709890
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.3.0.0-2TvPh8QGxerFYl5PoF1MSq
depends:
    aeson-2.2.2.0-6vy5nFkYOklEBUzF5CRv7u base-4.18.2.1 containers-0.6.7
    extra-1.7.16-ENixoDflt6v9pdHnDueJL0 ghc-9.6.6 ghc-boot-th-9.6.6
    ghc-exactprint-1.7.1.0-9dxxFYJ8S6M1cqjfcuhKUL
    ghcide-2.3.0.0-IAjr6FHxwDN2WHrf7xZzL8
    hls-plugin-api-2.3.0.0-IGiOca9xg6PAh9MaHX5nJX
    hls-refactor-plugin-2.3.0.0-1vR0D2G9jYk1XQ4Ce2vG2D
    lens-5.3.5-FTj0s0XQNe34VtbjGE3NFc
    lsp-2.2.0.0-5VWxu1we8UwCjDB58kn7YJ mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-CG6y7kseADB9y4YJD0dypo

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

